/*
 * Segment 2 (KEx), SWE LMS-TIC3
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.lmstic3.vew.daten.tic;

import java.util.ArrayList;
import java.util.List;

import de.bsvrz.kex.lmstic3.vew.daten.tic.elemente.TIC3Koordinaten;
import de.bsvrz.sys.funclib.bitctrl.geolib.WGS84Punkt;

/**
 * Utility-Klasse zur Koordinatenreduktion.
 *
 * @author BitCtrl Systems GmbH, Gieseler
 * @version $Id: $
 */

public final class KoordinatenReduktion {

	private KoordinatenReduktion() {

	}

	/**
	 * Reduziert die Koordinatenliste auf ein Raster.
	 * 
	 * @param koordinaten
	 *            Koordinatenliste
	 * @param raster
	 *            Raster
	 * @return reduzierte Koordinatenliste
	 */
	public static List<TIC3Koordinaten> reduziere(final List<TIC3Koordinaten> koordinaten, final int raster) {
		final List<TIC3Koordinaten> result = new ArrayList<>();

		if (koordinaten.size() == 0) {
			return result;
		}

		if (raster <= 0) {
			return koordinaten;
		}

		result.add(koordinaten.get(0));

		int start = 0;
		boolean lastfound = false;

		while (start >= 0) {
			final int idx = findNextPoint(koordinaten, start, raster);
			if (idx > 0) {
				result.add(koordinaten.get(idx));

				lastfound = idx == koordinaten.size() - 1;
			}

			start = idx;
		}

		if (!lastfound) {
			result.add(koordinaten.get(koordinaten.size() - 1));
		}

		return result;
	}

	/**
	 * <p>
	 * Um unnötige kurze Endstücke zu vermeiden, darf der letzte Abschnitt der
	 * Koordinatenliste dabei um bis zu ein Drittel des parametrierten Rasters
	 * verlängert werden.
	 * </p>
	 * 
	 * @param koordinaten
	 *            Liste der Koordinaten
	 * @param startindex
	 *            Startindex
	 * @param raster
	 *            Raster
	 * @return n&auml;chster Punkt
	 */
	private static int findNextPoint(final List<TIC3Koordinaten> koordinaten, final int startindex, final int raster) {
		final TIC3Koordinaten tic3Koordinate1 = koordinaten.get(startindex);
		final WGS84Punkt p1 = new WGS84Punkt(tic3Koordinate1.getLaenge(), tic3Koordinate1.getBreite());

		for (int i = startindex + 1; i < koordinaten.size(); i++) {
			final TIC3Koordinaten tic3Koordinate2 = koordinaten.get(i);

			final WGS84Punkt p2 = new WGS84Punkt(tic3Koordinate2.getLaenge(), tic3Koordinate2.getBreite());

			final double abstand = WGS84Punkt.abstand(p1, p2);

			if (abstand >= raster) {
				return i;
			}
		}

		return -1;
	}
}
