/*
 * Segment 2 (KEx), SWE LMS-TIC3
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.lmstic3.vew.daten.tic.elemente;

import org.w3c.dom.Node;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.kex.lmstic3.vew.daten.tic.TIC3Exception;
import de.bsvrz.kex.lmstic3.vew.daten.tic.TMCInteger;

/**
 * TIC3 LocationTypeEnum.
 * <p>Entspricht TIC3 XML Element: Type (TYP), TIC3 Info Typ 'LocationTypEnum'.</p>
 * 
 * @author BitCtrl Systems GmbH, Gieseler
 * @version $Id$
 */

public class TIC3LocationTyp extends TMCInteger {

	/**
	 * TIC3 XML Element: Type (TYP), TIC3 Info Typ 'LocationTypEnum'.
	 */
	private static final String XML_ELEMENT_LOCATIONTYPE = "Type";
	
	/**
	 * DAV-Attribut.
	 */
	private static final String DAV_ATTR_LOCATIONTYPE = "TIC3LocationType";
	
	
	/**
	 * Enumerator TIC3LocationTyp.
	 */
	public enum TIC3LocationTypEN {
		
		/** unbekannter Typ. */
		Unbekannt("Unbekannt", -1),

		/** Area. */
		Area("Gebiet", 0),

		/** Line (Strecke). */
		Line("Strecke", 1),

		/** Point. */
		Point("Punkt", 2);

		/**
		 * Gibt eine passende Status-Instanz zur&uuml;ck.
		 *
		 * @param id
		 *            numerischer Wert
		 * @return zum numerischen Wert passende Instanz
		 * @throws TIC3Exception
		 *             bei ung&uuml;ltigem Wert
		 */
		public static TIC3LocationTypEN getInstance(final int id) throws TIC3Exception {
			switch (id) {
			case -1:
				return Unbekannt;
			case 0:
				return Area;
			case 1:
				return Line;
			case 2:
				return Point;
			default:
				throw new TIC3Exception("Kein TIC3LocationTyp mit id=" + id + " definiert.");
			}
		}

		/**
		 * textueller Wert.
		 */
		private final String value;

		/**
		 * numerischer Wert.
		 */
		private int id;

		/**
		 * Privater Konstruktor.
		 *
		 * @param value
		 *            textueller Wert
		 * @param id
		 *            numerischer Wert
		 */
		TIC3LocationTypEN(final String value, final int id) {
			this.value = value;
			this.id = id;
		}

		/**
		 * Gibt den numerischen Wert zur&uuml;ck.
		 *
		 * @return numerischer Wert des Status
		 */
		public int getId() {
			return id;
		}

		/**
		 * Gibt den textuellen Wert zur&uuml;ck.
		 *
		 * @return textueller Wert des Status
		 */
		public String getValue() {
			return value;
		}
		
		@Override
		public String toString() {
			return value;
		}
	}

	/**
	 * TIC3LocationTypEN.
	 */
	private TIC3LocationTypEN locationTyp = TIC3LocationTypEN.Unbekannt;


	/**
	 * Konstruktor.
	 */
	public TIC3LocationTyp() {
		super(XML_ELEMENT_LOCATIONTYPE, DAV_ATTR_LOCATIONTYPE);
	}

	@Override
	public void getDavDaten(final Data davdata) throws TIC3Exception {
		locationTyp = TIC3LocationTypEN.getInstance(getWert());
	}

	@Override
	public void getXmlDaten(final Node node) throws TIC3Exception {
		locationTyp = TIC3LocationTypEN.getInstance(Integer.parseInt(node.getTextContent()));
	}

	@Override
	public void setDavDaten(final Data davdata) throws TIC3Exception {
		davdata.getUnscaledValue(getDavAttributName()).set(locationTyp.getId());
	}
	
	@Override
	public String toString() {
		return this.getClass().getSimpleName() + "='" + locationTyp + "'";
	}
}
