/*
 * Segment 2 (KEx), SWE LMS-TIC3
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.lmstic3.vew.daten.tic.elemente;

import de.bsvrz.kex.lmstic3.vew.daten.tic.AbstractTIC3InfoElement;

/**
 * TIC3 Umschlie&szlig;endes Gebiet.
 * 
 * <p>TIC3 Info XML Element: EnclosingArea (ARE), A list of enclosing areas.</p>
 * <p>Entspricht TIC3 AreaCategoryNameType.</p>
 *
 * @author BitCtrl Systems GmbH, Gieseler
 * @version $Id$
 */
public class TIC3NetzUmschliessendesGebiet extends AbstractTIC3InfoElement {

	/**
	 * TIC3 Info XML Element: EnclosingArea (ARE), A list of enclosing areas.
	 */
	public static final String XML_ELEMENT_NETWORKAREA_ENCLOSING = "EnclosingArea";

	/**
	 * DAV-Attribut.
	 */
	public static final String DAV_ATTR_NETWORKAREA_ENCLOSING = "TIC3UmschliessendesGebiet";

	/**
	 * Erzeugt ein neues Objekt.
	 */
	public TIC3NetzUmschliessendesGebiet() {
		super(XML_ELEMENT_NETWORKAREA_ENCLOSING, null);
		
		/** 
		 * Name des Gebietes.
		 * TIC3 Info XML Element: Name (NAM), The name of the object, in one or more languages configured on the system.
		 */
		addKindElement(new TIC3Text("Name", "TIC3GebietName"));
		
		/** 
		 * Kategorie des Gebietes.
		 * TIC3 Info XML Element: Category (CAT), The area category such as "Nature", "Administrative area", and "Built-up area".
		 */
		addKindElement(new TIC3Text("Category", "TIC3GebietKategorie"));
		
		/** 
		 * Unterkategorie des Gebietes.
		 * TIC3 Info XML Element: SubCategory (SCA), The area subcategory such as "Country", "Sea", or "Forest".
		 */
		addKindElement(new TIC3Text("SubCategory", "TIC3GebietUnterkategorie"));
	
		/** 
		 * Bekanntheit.
		 * TIC3 Info XML Element: Popularity (POP), The grade of popularity of the area in the range from 1 to 10, where 10 is the highest popularity grade.
		 */
		addKindElement(new TIC3Text("Popularity", "TIC3Bekanntheit"));
	}
}
