/*
 * Segment 2 (KEx), SWE LMS-TIC3
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.lmstic3.vew.daten.tic.elemente;

import org.w3c.dom.Node;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.kex.lmstic3.vew.LMSParameter;
import de.bsvrz.kex.lmstic3.vew.daten.tic.AbstractTIC3InfoElement;
import de.bsvrz.kex.lmstic3.vew.daten.tic.TIC3Exception;

/**
 * TIC3-Reiseiel.
 * <p>
 * Entspricht TIC3-Typ 'TIC3 DestinationType'.
 * </p>
 *
 * @author BitCtrl Systems GmbH, Gieseler
 * @version $Id$
 */
public class TIC3Reiseziel extends AbstractTIC3InfoElement {
	/**
	 * TIC3 Info XML Element: Destination (DST), The destination for which the
	 * diversion is specified.
	 */
	public static final String XML_ELEMENT_DESTINATION = "Destination";

	/**
	 * Name.
	 * <p>
	 * TIC3 Info XML Element: Name (NAM), The name of the object, in one or more
	 * languages configured on the system.
	 * </p>
	 */
	private final TIC3Text name = new TIC3Text("Name", "Name");

	/**
	 * Himmelsrichtung.
	 * <p>
	 * TIC3 Info XML Element: CompassDirection (CPS), The name corresponding to
	 * a compass direction such as "North", "South", "East", or "West".
	 * </p>
	 */
	private final TIC3Himmelsrichtung richtung = new TIC3Himmelsrichtung("CompassDirection", "Himmelsrichtung");

	private boolean hasData;

	/**
	 * Erzeugt ein neues Objekt.
	 *
	 * @param xmlName
	 *            Name des XML-ELementes
	 * @param davName
	 *            Name des DAV-Attributes
	 */
	public TIC3Reiseziel(final String xmlName, final String davName) {
		super(xmlName, davName);
		addKindElement(name);
		addKindElement(richtung);
	}

	@Override
	public void publizieren(final Data davdata, final LMSParameter parameter) throws TIC3Exception {
		if (hasData) {
			super.publizieren(davdata, parameter);
		}
	}

	@Override
	public void einlesenXML(final Node node) throws TIC3Exception {
		super.einlesenXML(node);
		hasData = true;
	}

	@Override
	public String toString() {
		return this.getClass().getSimpleName();
	}
}
