/*
 * Segment 2 (KEx), SWE LMS-TIC3
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.lmstic3.vew.daten.tic.elemente;

import de.bsvrz.kex.lmstic3.vew.daten.tic.AbstractTIC3InfoElement;

/**
 * TIC3-Informationen zur Location-Tabelle.
 * <p>Fasst die Elemente zur Locationtabelle zusammen.</p>
 *
 * @author BitCtrl Systems GmbH, Gieseler
 * @version $Id$
 */
public class TIC3TMCLocationTabelleInfo extends AbstractTIC3InfoElement {

	/**
	 * Erweiterter Ländercode der Locationtabelle.
	 * <p>(Wird hier als Text modelliert, da uns aktuell die IEC 62106 nicht vorliegt)</p>
	 */
	private TIC3Text locationTabelleErweiterterLandescode = new TIC3Text("LocationTableExtendedCountryCode", "LocationTabelleErweiterterLandescode");
	
	/**
	 * Ländercode der Locationtabelle.
	 * <p>(Wird hier als Text modelliert, da uns aktuell die IEC 62106 nicht vorliegt)</p>
	 */
	private TIC3Text locationTabelleLandescode = new TIC3Text("LocationTableCountryCode", "LocationTabelleLandescode");

	/**
	 * Nummer der Locationtabelle.
	 */
	private TIC3Text locationTabelleNummer = new TIC3Text("LocationTableNumber", "LocationTabelleNummer");
	
	/**
	 * Version der Locationtabelle.
	 */
	private TIC3Text locationTabelleVersion = new TIC3Text("LocationTableVersion", "LocationTabelleVersion");

	
	/**
	 * Erzeugt ein neues Objekt.
	 */
	public TIC3TMCLocationTabelleInfo() {
		super("", "LocationTabelleInfo");
		addKindElement(locationTabelleErweiterterLandescode);
		addKindElement(locationTabelleLandescode);
		addKindElement(locationTabelleNummer);
		addKindElement(locationTabelleVersion);
	}


	@Override
	public String toString() {
		return this.getClass().getSimpleName() + ": erw.Landescode: " + locationTabelleErweiterterLandescode.getText() 
				+ ", Landescode: " + locationTabelleLandescode.getText()
				+ ", Nummer: " + locationTabelleNummer.getText()
				+ ", Version: " + locationTabelleVersion.getText();
	}
}
