/*
 * Segment 2 (KEx), SWE LMS-TIC3
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.lmstic3.vew.daten.tic.elemente;

import org.w3c.dom.Element;
import org.w3c.dom.Node;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.kex.lmstic3.vew.daten.tic.TIC3Exception;
import de.bsvrz.kex.lmstic3.vew.daten.tic.TMCInteger;

/**
 * TIC3 'TmcEventCodeTypeEnum'.
 * 
 * @author BitCtrl Systems GmbH, Gieseler
 * @version $Id$
 */

public class TIC3TmcEventCodeTyp extends TMCInteger {

	/**
	 * TIC3 Info XML Element: Type (TYP), The type of TMC event code such as "Event code" or "Supplementary information code".
	 */
	private static final String XML_ELEMENT_EVENTTYPE = "Type";
	
	/**
	 * DAV-Attribut.
	 */
	private static final String DAV_ATTR_EVENTTYPE = "Type";
	
	
	/**
	 * Enumerator TIC3TmcEventCodeTypEN.
	 */
	public enum TIC3TmcEventCodeTypEN {
		
		/** unbekannter Typ. */
		Unbekannt("Unbekannt", -1),

		/** Ereigniscode. */
		Ereigniscode("Ereigniscode", 1),

		/** Zusatzempfehlungscode. */
		Zusatzempfehlungscode("Zusatzempfehlungscode", 2);


		/**
		 * Gibt eine passende Status-Instanz zur&uuml;ck.
		 *
		 * @param id
		 *            numerischer Wert
		 * @return zum numerischen Wert passende Instanz
		 * @throws TIC3Exception
		 *             bei ung&uuml;ltigem Wert
		 */
		public static TIC3TmcEventCodeTypEN getInstance(final int id) throws TIC3Exception {
			switch (id) {
			case -1:
				return Unbekannt;
			case 1:
				return Ereigniscode;
			case 2:
				return Zusatzempfehlungscode;
			default:
				throw new TIC3Exception("Kein TIC3LocationTyp mit id=" + id + " definiert.");
			}
		}

		/**
		 * textueller Wert.
		 */
		private final String value;

		/**
		 * numerischer Wert.
		 */
		private int id;

		/**
		 * Privater Konstruktor.
		 *
		 * @param value
		 *            textueller Wert
		 * @param id
		 *            numerischer Wert
		 */
		TIC3TmcEventCodeTypEN(final String value, final int id) {
			this.value = value;
			this.id = id;
		}

		/**
		 * Gibt den numerischen Wert zur&uuml;ck.
		 *
		 * @return numerischer Wert des Status
		 */
		public int getId() {
			return id;
		}

		/**
		 * Gibt den textuellen Wert zur&uuml;ck.
		 *
		 * @return textueller Wert des Status
		 */
		public String getValue() {
			return value;
		}
		
		@Override
		public String toString() {
			return value;
		}
	}

	/**
	 * TIC3LocationTypEN.
	 */
	private TIC3TmcEventCodeTypEN eventTyp = TIC3TmcEventCodeTypEN.Unbekannt;


	public TIC3TmcEventCodeTypEN getEventTyp() {
		return eventTyp;
	}
	
	public void setEventTyp(final TIC3TmcEventCodeTypEN typ) {
		eventTyp = typ;
		setWert(typ.id);
	}

	/**
	 * Konstruktor.
	 */
	public TIC3TmcEventCodeTyp() {
		super(XML_ELEMENT_EVENTTYPE, DAV_ATTR_EVENTTYPE);
	}
	
	@Override
	public void getDavDaten(final Data davdata) throws TIC3Exception {
		eventTyp = TIC3TmcEventCodeTypEN.getInstance(getWert());
	}

	@Override
	public void getXmlDaten(final Node node) throws TIC3Exception {
		eventTyp = TIC3TmcEventCodeTypEN.getInstance(Integer.parseInt(node.getTextContent()));
	}
	
	@Override
	public void setXmlDaten(final Element element) {
		element.setTextContent(String.valueOf(eventTyp.id));
	}

	@Override
	public void setDavDaten(final Data davdata) throws TIC3Exception {
		davdata.getUnscaledValue(getDavAttributName()).set(eventTyp.getId());
	}
	
	@Override
	public String toString() {
		return this.getClass().getSimpleName() + "='" + eventTyp + "'";
	}
}
