/*
 * Segment 2 (KEx), SWE LMS-TIC3
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.lmstic3.vew.daten.tmc;

import de.bsvrz.kex.lmstic3.vew.daten.tic.TIC3Exception;
import de.bsvrz.kex.lmstic3.vew.daten.tic.TMCInteger;

/**
 * TMC-Richtung.
 *
 * @author BitCtrl Systems GmbH, Gieseler
 * @version $Id$
 */

public class TMCRichtung extends TMCInteger {

	/**
	 * Enumerator TIC3-Richtung.
	 */
	public enum TMCRichtungEnum {

		/** negativ. */
		Negativ("negativ", -1),

		/** ohne Richtung. */
		OhneRichtung("ohne Richtung", 0),

		/** positiv. */
		Positiv("positiv", 1);

		/**
		 * Gibt eine passende Richtung-Instanz zur&uuml;ck.
		 *
		 * @param id
		 *            numerischer Wert
		 * @return zum numerischen Wert passende Instanz
		 * @throws TIC3Exception
		 *             bei ung&uuml;ltigem Wert
		 */
		public static TMCRichtungEnum getInstance(final int id) throws TIC3Exception {
			switch (id) {
			case -1:
				return Negativ;
			case 0:
				return TMCRichtungEnum.OhneRichtung;
			case 1:
				return Positiv;
			default:
				throw new TIC3Exception("Keine TMC-Richtung mit id=" + id + " definiert.");
			}
		}

		/**
		 * textueller Wert.
		 */
		private final String value;

		/**
		 * numerischer Wert.
		 */
		private int id;

		/**
		 * Privater Konstruktor.
		 *
		 * @param value
		 *            textueller Wert
		 * @param id
		 *            numerischer Wert
		 */
		TMCRichtungEnum(final String value, final int id) {
			this.value = value;
			this.id = id;
		}

		/**
		 * Gibt den numerischen Wert zur&uuml;ck.
		 *
		 * @return numerischer Wert der Richtung
		 */
		public int getId() {
			return id;
		}

		/**
		 * Gibt den textuellen Wert zur&uuml;ck.
		 *
		 * @return textueller Wert der Richtung
		 */
		public String getValue() {
			return value;
		}
	}

	/**
	 * Erzeugt ein neues Objekt.
	 *
	 * @param xmlName
	 *            Name des XML-ELementes
	 * @param davName
	 *            Name des DAV-Attributes
	 */
	public TMCRichtung(final String xmlName, final String davName) {
		super(xmlName, davName);
	}
}
